const express = require('express');
const { readFile } = require('fs').promises;
const { generateCallHTML } = require('./src/html/callHTML.js');
const { getRandomUser } = require('./src/database/getUser.js');

function launchWeb(submitEvent){
    const app = express();

    app.use(express.json()); // Used to parse JSON bodies
    app.use(express.urlencoded({ extended: false })); //Parse URL-encoded bodies

    app.use('/assets', express.static('./www/assets'))

    app.get('/', async (request, response) => {
        response.send(await readFile('./www/index.html', 'utf8'));
    });
    app.get('/call', async (request, response) => {
        response.send(await generateCallResponse());
    });

    app.post('/inputs/call', async (request, response) => {
        submitEvent.emit('call', request.body);
        response.send(await generateCallResponse());
    });
    app.post('/inputs/add', async (request, response) => {
        submitEvent.emit('add', request);
    });

    const PORT = process.env.PORT || 3000;
    app.listen(PORT, () => { console.log(`App available at http://localhost:${PORT}`) });
};

async function generateCallResponse(){
    const user = await getRandomUser();
    let callHTML;
    if(user) callHTML = generateCallHTML( user.phone, user.name, user.count );
    else callHTML = `Plus d'utilisateur à appeler !`;
    return callHTML;
}

module.exports = { launchWeb };
